@mixin transform($property: none) {
//  none | <transform-function>
  -webkit-transform: $property;
     -moz-transform: $property;
      -ms-transform: $property;
       -o-transform: $property;
          transform: $property;
}

@mixin transform-origin($axes: 50%) {
// x-axis - left | center | right  | length | %
// y-axis - top  | center | bottom | length | %
// z-axis -                          length
  -webkit-transform-origin: $axes;
     -moz-transform-origin: $axes;
      -ms-transform-origin: $axes;
       -o-transform-origin: $axes;
          transform-origin: $axes;
}
